==> vlconfig2-7.0-x86_64.tar.xz: install/doinst.sh <==
#!/bin/sh

#!/bin/bash

rm -f etc/rc.d/rc4.d/*

# now some hardware setup
depmod -aq
if [ -d usr/lib64 ];then
	libdirsuffix=64
fi
( cd usr/lib${libdirsuffix} && ln -sf preloadable_libintl.so libgnuintl.so.8 && rm libintl.so 2>/dev/null; ln -sf preloadable_libintl.so libintl.so )


cp -ax etc/skel/.config/cairo-dock root/.config/cairo-dock
#( cd etc/gtk-2.0 ; rm -rf gtkrc )
#( cd etc/gtk-2.0 ; ln -sf /usr/share/themes/QtCurve/gtk-2.0/gtkrc gtkrc )

( cd etc/X11/xinit ; rm -rf xinitrc )
( cd etc/X11/xinit ; ln -sf xinitrc.xfce xinitrc )

( cd etc/skel ; rm -rf .profile )
( cd etc/skel ; ln -sf .bash_profile .profile )
( cd root ; rm -rf .profile )
( cd root ; ln -sf .bash_profile .profile )
( cp -ax etc/skel/.config/cairo-dock/ root/.config/ )

( cd etc/skel ; rm -rf .profile )
( cd etc/skel ; ln -sf .bash_profile .profile )
( cd etc/skel/.wicd ; rm -rf WHEREAREMYFILES )
( cd etc/skel/.wicd ; ln -sf /var/lib/wicd/WHEREAREMYFILES WHEREAREMYFILES )

( cd usr/sbin ; rm -rf iptables )
( cd usr/sbin ; ln -sf /sbin/iptables iptables )

( cd sbin && rm -f service; ln -sf /etc/rc.d/service service )

chroot /mnt/target depmod -aq &>/dev/null


( cd usr/share/icons/Tango/16x16/mimetypes ; rm -rf gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/16x16/mimetypes ; ln -sf /usr/share/pixmaps/txz-icon.png gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/16x16/mimetypes ; rm -rf gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/16x16/mimetypes ; ln -sf /usr/share/pixmaps/tlz-icon.png gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/22x22/mimetypes ; rm -rf gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/22x22/mimetypes ; ln -sf /usr/share/pixmaps/txz-icon.png gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/22x22/mimetypes ; rm -rf gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/22x22/mimetypes ; ln -sf /usr/share/pixmaps/tlz-icon.png gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/24x24/mimetypes ; rm -rf gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/24x24/mimetypes ; ln -sf /usr/share/pixmaps/txz-icon.png gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/24x24/mimetypes ; rm -rf gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/24x24/mimetypes ; ln -sf /usr/share/pixmaps/tlz-icon.png gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/32x32/mimetypes ; rm -rf gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/32x32/mimetypes ; ln -sf /usr/share/pixmaps/txz-icon.png gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/32x32/mimetypes ; rm -rf gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/32x32/mimetypes ; ln -sf /usr/share/pixmaps/tlz-icon.png gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/scalable/mimetypes ; rm -rf gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/scalable/mimetypes ; ln -sf /usr/share/pixmaps/txz-icon.png gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/scalable/mimetypes ; rm -rf gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/scalable/mimetypes ; ln -sf /usr/share/pixmaps/tlz-icon.png gnome-mime-application-x-compressed-tlz.png )

==> vlconfig2-7.1-x86_64.tar.xz: install/doinst.sh <==
#!/bin/sh

rm -f etc/rc.d/rc4.d/*

# now some hardware setup
depmod -aq
	libdirsuffix=64
( cd usr/lib${libdirsuffix} && ln -sf preloadable_libintl.so libgnuintl.so.8 && rm libintl.so 2>/dev/null; ln -sf preloadable_libintl.so libintl.so )


cp -ax etc/skel/.config/cairo-dock root/.config/cairo-dock
#( cd etc/gtk-2.0 ; rm -rf gtkrc )
#( cd etc/gtk-2.0 ; ln -sf /usr/share/themes/QtCurve/gtk-2.0/gtkrc gtkrc )

( cd etc/X11/xinit ; rm -rf xinitrc )
( cd etc/X11/xinit ; ln -sf xinitrc.xfce xinitrc )

( cd etc/skel ; rm -rf .profile )
( cd etc/skel ; ln -sf .bash_profile .profile )
( cd root ; rm -rf .profile )
( cd root ; ln -sf .bash_profile .profile )
( cp -ax etc/skel/.config/cairo-dock/ root/.config/ )

( cd etc/skel ; rm -rf .profile )
( cd etc/skel ; ln -sf .bash_profile .profile )
( cd etc/skel/.wicd ; rm -rf WHEREAREMYFILES )
( cd etc/skel/.wicd ; ln -sf /var/lib/wicd/WHEREAREMYFILES WHEREAREMYFILES )

( cd usr/sbin ; rm -rf iptables )
( cd usr/sbin ; ln -sf /sbin/iptables iptables )

( cd sbin && rm -f service; ln -sf /etc/rc.d/service service )

chroot /mnt/target depmod -aq &>/dev/null


( cd usr/share/icons/Tango/16x16/mimetypes ; rm -rf gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/16x16/mimetypes ; ln -sf /usr/share/pixmaps/txz-icon.png gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/16x16/mimetypes ; rm -rf gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/16x16/mimetypes ; ln -sf /usr/share/pixmaps/tlz-icon.png gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/22x22/mimetypes ; rm -rf gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/22x22/mimetypes ; ln -sf /usr/share/pixmaps/txz-icon.png gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/22x22/mimetypes ; rm -rf gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/22x22/mimetypes ; ln -sf /usr/share/pixmaps/tlz-icon.png gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/24x24/mimetypes ; rm -rf gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/24x24/mimetypes ; ln -sf /usr/share/pixmaps/txz-icon.png gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/24x24/mimetypes ; rm -rf gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/24x24/mimetypes ; ln -sf /usr/share/pixmaps/tlz-icon.png gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/32x32/mimetypes ; rm -rf gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/32x32/mimetypes ; ln -sf /usr/share/pixmaps/txz-icon.png gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/32x32/mimetypes ; rm -rf gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/32x32/mimetypes ; ln -sf /usr/share/pixmaps/tlz-icon.png gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/scalable/mimetypes ; rm -rf gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/scalable/mimetypes ; ln -sf /usr/share/pixmaps/txz-icon.png gnome-mime-application-x-compressed-txz.png )
( cd usr/share/icons/Tango/scalable/mimetypes ; rm -rf gnome-mime-application-x-compressed-tlz.png )
( cd usr/share/icons/Tango/scalable/mimetypes ; ln -sf /usr/share/pixmaps/tlz-icon.png gnome-mime-application-x-compressed-tlz.png )

chmod +x etc/rc.d/rc.udev

( cd etc/rc.d/rc4.d ; rm -rf K49networkmanager )
( cd etc/rc.d/rc4.d ; ln -sf ../init.d/networkmanager K49networkmanager )
( cd etc/rc.d/rc4.d ; rm -rf S50networkmanager )
( cd etc/rc.d/rc4.d ; ln -sf ../init.d/networkmanager S50networkmanager )
